<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Core\Model\Configuration;
use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Cms\Model\ResourceModel\Page\CollectionFactory as PageCollectionFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManagerInterface;
use MongoDB\Driver\Exception\Exception;
use stdClass;

/**
 * Class CmsPage
 * @package FiloBlu\Refilo\Model\Exporter
 */
class CmsPage extends AbstractCmsExporter
{
    /**
     * @var PageCollectionFactory
     */
    protected $pageCollectionFactory;
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;

    /**
     * Menu constructor.
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     * @param Mongo $mongo
     * @param StoreManagerInterface $storeManager
     * @param Configuration $coreConfiguration
     * @param PageCollectionFactory $pageCollectionFactory
     */
    public function __construct(
        ResourceConnection $resourceConnection,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo,
        StoreManagerInterface $storeManager,
        Configuration $coreConfiguration,
        PageCollectionFactory $pageCollectionFactory
    )
    {
        parent::__construct($mongo, $coreConfiguration, $scopeConfig, $storeManager);
        $this->resourceConnection = $resourceConnection;
        $this->pageCollectionFactory = $pageCollectionFactory;
    }

    /**
     *
     */
    public function execute()
    {
        foreach ($this->getStoreManager()->getStores() as $store) {

            $pages = $this->pageCollectionFactory->create()
                ->addStoreFilter($store)
                ->addFilter('is_active', 1);

            $bulk = [];
            foreach ($pages as $item) {
                $block = new stdClass();

                $block->_id = 'page_' . $item->getId() . '_' . $store->getData('code');
                $block->metacode = 'page';
                $block->store = $store->getData('code');
                $block->content_id = (int)$item->getId();
                $block->url_key = $item->getIdentifier();
                $block->idx = $item->getIdentifier();
                $block->title = $item->getTitle();
                $block->type = 'page';
                $block->meta_title = $item->getMetaTitle();
                $block->meta_description = $item->getMetaDescription();
                $block->meta_keywords = $item->getMetaKeywords();
                $block->content_heading = $item->getContentHeading();
                $block->refilo_layout = $item->getRefiloLayout();
                $block->refilo_template = $item->getRefiloTemplate();
                $block->heading_visible = boolval($item->getHeadingVisible());
                $block->breadcrumbs_visible = boolval($item->getBreadcrumbsVisible());
                $block->og_data_image = $item->getOgDataImage();
                $block->header_type = $item->getHeaderType();
                $block->css_class = $item->getCssClass();
                $block->css_style = $item->getCssStyle();
                $block->robots = $item->getRobots();
                $block->status = $item->isActive();
                $block->content = $item->getContent();

                $bulk[] = $block;
            }

            try {
                $this->getConnection()->update(
                    '_id',
                    $bulk,
                    'contents_' . $store->getCode(),
                    true,
                    $this->getDatabaseByWebsiteCode($store->getWebsite()->getCode())
                );
            } catch (Exception $e) {
                echo $e->getMessage();
            }

        }
    }

    public function getMetaCode(): string
    {
        return 'page';
    }

    public function getCollectionPrefix(): string
    {
        return 'contents_';
    }
}
