<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Core\Model\Configuration;
use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\State;
use Magento\Framework\Translate;
use Magento\Framework\Translate\ResourceInterface;
use Magento\Store\Api\StoreConfigManagerInterface;
use MongoDB\Driver\Exception\Exception;

/**
 * Class Translations
 * @package FiloBlu\Refilo\Model\Exporter
 */
class Translations extends AbstractExporter
{
    /**
     * @var Translate
     */
    private $translate;

    /**
     * @var StoreConfigManagerInterface
     */
    private $storeConfigManager;

    /**
     * @var State
     */
    private $state;

    /**
     * Translations constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param ResourceInterface $translate
     * @param StoreConfigManagerInterface $storeConfigManager
     * @param State $state
     * @param Mongo $mongo
     * @param Configuration $coreConfiguration
     */
    public function __construct(
        ScopeConfigInterface $scopeConfig,
        ResourceInterface $translate,
        StoreConfigManagerInterface $storeConfigManager,
        State $state,
        Mongo $mongo,
        Configuration $coreConfiguration

    )
    {
        parent::__construct($mongo, $coreConfiguration, $scopeConfig);
        $this->translate = $translate;
        $this->storeConfigManager = $storeConfigManager;
        $this->state = $state;

    }

    /**
     * @return iterable
     */
    public function getCollections(): iterable
    {
        yield 'translations';
    }

    /**
     * @throws Exception
     */
    public function execute()
    {

        $id = 1;

        foreach ($this->getLocales() as $locale) {

            $bulkData = [];
            $data = $this->translate->getTranslationArray(null, $locale);

            foreach ($data as $string => $translation) {
                $bulkData[] = [
                    '_id'         => $id++,
                    'string'      => $string,
                    'translation' => strtr($translation, ['&#039;' => '\'']),
                    'locale_code' => $locale
                ];
            }

            $this->write($bulkData);
        }
    }

    /**
     * @return array
     */
    public function getLocales()
    {
        $locales = [];

        foreach ($this->storeConfigManager->getStoreConfigs() as $storeConfig) {
            $locales[] = $storeConfig->getLocale();
        }

        return array_unique($locales);
    }

    /**
     * @param array $bulkData
     */
    public function write(array $bulkData)
    {
        if (empty($bulkData)) {
            return;
        }

        $projectIds = [$this->getDatabase()];

        if ($this->getCoreConfiguration()->isMultiDomain()) {
            $projectIds = $this->getCoreConfiguration()->getProjectIds();
        }

        try {
            foreach ($projectIds as $projectId) {
                $this->getConnection()->update('_id', $bulkData, 'translations', true, $projectId);
            }
        } catch (Exception $e) {
            echo $e->getMessage();
        }

    }
}
